"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const QuestionTitle_1 = tslib_1.__importDefault(require("../QuestionTitle/QuestionTitle"));
const QuestionDescription_1 = tslib_1.__importDefault(require("../QuestionDescription/QuestionDescription"));
const utils_1 = require("../../utils");
const context_1 = tslib_1.__importDefault(require("../CioQuiz/context"));
const ControlBar_1 = tslib_1.__importDefault(require("../ControlBar/ControlBar"));
function OpenTextQuestion(props) {
    var _a;
    const { initialValue = '', onChangeHandler: userDefinedHandler = null } = props;
    const { state, previousQuestion, nextQuestion } = (0, react_1.useContext)(context_1.default);
    const [openTextInput, setOpenTextInput] = (0, react_1.useState)(initialValue);
    let question;
    if (state === null || state === void 0 ? void 0 : state.quiz.currentQuestion) {
        question = state === null || state === void 0 ? void 0 : state.quiz.currentQuestion.next_question;
    }
    const onChangeHandler = (e) => {
        setOpenTextInput(e.target.value);
        if (userDefinedHandler) {
            userDefinedHandler(e);
        }
    };
    const onNextClick = () => {
        if (nextQuestion && openTextInput) {
            nextQuestion(openTextInput);
        }
    };
    const onKeyDownHandler = (e) => {
        const { key } = e;
        if (key === 'Enter') {
            onNextClick();
        }
    };
    (0, react_1.useEffect)(() => {
        var _a, _b;
        if (state === null || state === void 0 ? void 0 : state.quiz.currentQuestion) {
            const questionId = (_a = state === null || state === void 0 ? void 0 : state.quiz.currentQuestion) === null || _a === void 0 ? void 0 : _a.next_question.id;
            const currentAnswer = (_b = state.answers.inputs) === null || _b === void 0 ? void 0 : _b[questionId];
            const openTextAnswer = currentAnswer || initialValue;
            setOpenTextInput(openTextAnswer);
        }
    }, [state, initialValue]);
    if (question) {
        const hasImage = (_a = question === null || question === void 0 ? void 0 : question.images) === null || _a === void 0 ? void 0 : _a.primary_url;
        return (react_1.default.createElement("div", { className: `
          cio-container${hasImage ? '--with-image' : ''}
          cio-open-text-question-container${hasImage ? '--with-image' : ''}
        `, "data-question-key": question.key },
            hasImage ? (0, utils_1.renderImages)(question.images, 'cio-question-image-container') : '',
            react_1.default.createElement("div", { className: 'cio-question-content' },
                react_1.default.createElement(QuestionTitle_1.default, { title: question.title }),
                react_1.default.createElement(QuestionDescription_1.default, { description: question.description }),
                react_1.default.createElement("input", { className: 'cio-question-input-text', placeholder: question.input_placeholder || 'Answer here...', value: openTextInput, onChange: onChangeHandler, onKeyDown: onKeyDownHandler }),
                react_1.default.createElement(ControlBar_1.default, { nextButtonHandler: onNextClick, isNextButtonDisabled: !openTextInput, backButtonHandler: previousQuestion, showBackButton: !(state === null || state === void 0 ? void 0 : state.quiz.isFirstQuestion), ctaButtonText: question === null || question === void 0 ? void 0 : question.cta_text }))));
    }
    return null;
}
exports.default = OpenTextQuestion;
