"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = require("react");
const actions_1 = require("../components/CioQuiz/actions");
const quizApiReducer_1 = tslib_1.__importStar(require("../components/CioQuiz/quizApiReducer"));
const services_1 = require("../services");
const useFetchQuiz = (quizId, quizLocalState, dispatchLocalState, resultsPageOptions, quizVersionIdProp, cioClient) => {
    var _a, _b;
    const [quizApiState, dispatch] = (0, react_1.useReducer)(quizApiReducer_1.default, quizApiReducer_1.initialState);
    const firstQuestionId = (_a = quizApiState.quizFirstQuestion) === null || _a === void 0 ? void 0 : _a.next_question.id;
    const currentQuestionId = (_b = quizApiState.quizCurrentQuestion) === null || _b === void 0 ? void 0 : _b.next_question.id;
    const isFirstQuestion = firstQuestionId === currentQuestionId;
    (0, react_1.useEffect)(() => {
        (() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            dispatch({
                type: actions_1.QuizAPIActionTypes.SET_IS_LOADING,
            });
            if (quizLocalState.isLastAnswer) {
                try {
                    const quizResults = yield (0, services_1.getQuizResults)(cioClient, quizId, {
                        answers: quizLocalState.answers,
                        resultsPerPage: resultsPageOptions === null || resultsPageOptions === void 0 ? void 0 : resultsPageOptions.numResultsToDisplay,
                        quizVersionId: quizLocalState.quizVersionId,
                        quizSessionId: quizLocalState.quizSessionId,
                    });
                    // Set quiz results state
                    dispatch({
                        type: actions_1.QuizAPIActionTypes.SET_QUIZ_RESULTS,
                        payload: {
                            quizResults,
                        },
                    });
                }
                catch (error) {
                    dispatch({
                        type: actions_1.QuizAPIActionTypes.SET_IS_ERROR,
                    });
                }
            }
            else {
                try {
                    const quizVersionId = quizLocalState.quizVersionId || quizVersionIdProp;
                    const { quizSessionId } = quizLocalState;
                    const questionResult = yield (0, services_1.nextQuestion)(cioClient, quizId, {
                        answers: quizLocalState.answers,
                        quizVersionId,
                        quizSessionId,
                    });
                    // Update quizSessionId, quizVersionId
                    if ((!quizSessionId && (questionResult === null || questionResult === void 0 ? void 0 : questionResult.quiz_session_id)) ||
                        (!quizVersionId && questionResult.quiz_version_id)) {
                        dispatchLocalState({
                            type: actions_1.QuestionTypes.Hydrate,
                            payload: {
                                quizVersionId: questionResult === null || questionResult === void 0 ? void 0 : questionResult.quiz_version_id,
                                quizSessionId: questionResult === null || questionResult === void 0 ? void 0 : questionResult.quiz_session_id,
                            },
                        });
                    }
                    // Set current question state
                    dispatch({
                        type: actions_1.QuizAPIActionTypes.SET_CURRENT_QUESTION,
                        payload: {
                            quizCurrentQuestion: questionResult,
                        },
                    });
                }
                catch (error) {
                    dispatch({
                        type: actions_1.QuizAPIActionTypes.SET_IS_ERROR,
                    });
                }
            }
        }))();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [
        cioClient,
        quizId,
        quizLocalState.answers,
        quizLocalState.isLastAnswer,
        resultsPageOptions === null || resultsPageOptions === void 0 ? void 0 : resultsPageOptions.numResultsToDisplay,
    ]);
    const resetQuizApiState = () => {
        dispatch({ type: actions_1.QuizAPIActionTypes.RESET_QUIZ });
    };
    return {
        cioClient,
        quizApiState,
        isFirstQuestion,
        resetQuizApiState,
    };
};
exports.default = useFetchQuiz;
