import React, { useContext } from 'react';
import ResultCtaButton from '../ResultCtaButton/ResultCtaButton';
import QuizContext from '../CioQuiz/context';
export default function ResultCard(props) {
    const { result, salePriceKey, regularPriceKey, resultPosition } = props;
    const { resultClick, customClickItemCallback } = useContext(QuizContext);
    const salePrice = salePriceKey && result?.data?.[salePriceKey];
    const regularPrice = regularPriceKey && result?.data?.[regularPriceKey];
    const clickHandler = () => {
        if (resultClick) {
            resultClick(result, resultPosition);
        }
    };
    const keyDownHandler = (event) => {
        if (event?.key === ' ' || event?.key === 'Enter') {
            if (resultClick) {
                resultClick(result, resultPosition);
            }
        }
    };
    const resultCardContent = () => (React.createElement(React.Fragment, null,
        React.createElement("div", { className: 'cio-result-card-image' },
            React.createElement("img", { src: result.data?.image_url, alt: 'product' })),
        React.createElement("div", { className: 'cio-result-card-text' },
            React.createElement("p", { className: 'cio-result-card-title' }, result.value),
            React.createElement("div", { className: 'cio-result-card-prices' },
                salePrice && React.createElement("span", { className: 'cio-result-card-sale-price' },
                    "$",
                    salePrice),
                regularPrice && (React.createElement("span", { className: `cio-result-card-regular-price${salePrice ? '--strike-through' : ''}` },
                    "$",
                    regularPrice))))));
    const resultCardContentWithoutLink = () => (React.createElement("div", { className: 'cio-result-card-container', onClick: () => clickHandler(), onKeyDown: (e) => keyDownHandler(e), role: 'button', tabIndex: 0 }, resultCardContent()));
    const resultCardContentWithLink = () => (React.createElement("a", { className: 'cio-result-card-anchor', href: result.data?.url, onClick: () => clickHandler(), onKeyDown: (e) => keyDownHandler(e) }, resultCardContent()));
    return (React.createElement("div", { className: 'cio-result-card' },
        !customClickItemCallback ? resultCardContentWithLink() : resultCardContentWithoutLink(),
        React.createElement(ResultCtaButton, { item: result, price: salePrice || regularPrice })));
}
