/// <reference types="react" />
import { QuizResultData, NextQuestionResponse, QuizResultsResponse } from '@constructor-io/constructorio-client-javascript/lib/types';
import ConstructorIOClient from '@constructor-io/constructorio-client-javascript';
import { RequestStates } from './constants';
export type { QuestionOption, QuestionImages, Question, NextQuestionResponse, QuizResultsResponse, BrowseResultData, BrowseRequestType, QuizzesParameters, QuizzesResultsParameters, } from '@constructor-io/constructorio-client-javascript/lib/types';
export type QuizResultDataPartial = Partial<QuizResultData>;
export interface ResultsProps {
    resultCardSalePriceKey?: string;
    resultCardRegularPriceKey?: string;
}
export declare namespace QuizResultsEventsProps {
    type OnQuizResultsLoaded = (results: QuizResultDataPartial) => void;
    type OnQuizResultClick = (result: QuizResultDataPartial, position: number) => void;
    type OnAddToCartClick = (result: QuizResultDataPartial) => void;
}
export interface ResultsPageOptions extends ResultsProps {
    numResultsToDisplay?: number;
    onQuizResultsLoaded?: QuizResultsEventsProps.OnQuizResultsLoaded;
    onQuizResultClick?: QuizResultsEventsProps.OnQuizResultClick;
    onAddToCartClick: QuizResultsEventsProps.OnAddToCartClick;
}
export interface SessionStateOptions {
    showSessionModal?: boolean;
    sessionStateKey?: string;
}
export interface IQuizProps {
    apiKey?: string;
    cioJsClient?: ConstructorIOClient;
    quizId: string;
    quizVersionId?: string;
    resultsPageOptions: ResultsPageOptions;
    sessionStateOptions?: SessionStateOptions;
    primaryColor?: string;
}
export interface QuizReturnState {
    answers: {
        inputs: Record<string, string | string[]>;
        isLastAnswer: boolean;
    };
    quiz: {
        requestState: RequestStates;
        versionId?: string;
        sessionId?: string;
        firstQuestion?: NextQuestionResponse;
        currentQuestion?: NextQuestionResponse;
        results?: QuizResultsResponse;
        resultsFilters?: string[];
        isFirstQuestion?: boolean;
    };
}
export declare namespace QuizEventsReturn {
    type NextQuestion = (payload?: string | string[]) => void;
    type PreviousQuestion = () => void;
    type ResetQuiz = () => void;
    type ResultClick = (result: QuizResultDataPartial, position: number) => void;
    type AddToCart = (e: React.MouseEvent<HTMLElement>, result: QuizResultDataPartial, price?: number) => void;
    type HydrateQuiz = () => void;
    type HasStoredState = () => boolean;
    type ResetStoredState = () => void;
}
export interface QuizEventsReturn {
    nextQuestion: QuizEventsReturn.NextQuestion;
    previousQuestion: QuizEventsReturn.PreviousQuestion;
    resetQuiz: QuizEventsReturn.ResetQuiz;
    resultClick: QuizEventsReturn.ResultClick;
    addToCart: QuizEventsReturn.AddToCart;
    hydrateQuiz: QuizEventsReturn.HydrateQuiz;
    hasStoredState: QuizEventsReturn.HasStoredState;
    resetStoredState: QuizEventsReturn.ResetStoredState;
}
export interface PrimaryColorStyles {
    '--primary-color-h': string;
    '--primary-color-s': string;
    '--primary-color-l': string;
}
export interface UseQuizReturn {
    cioClient?: ConstructorIOClient;
    state: QuizReturnState;
    events: QuizEventsReturn;
    primaryColorStyles: PrimaryColorStyles;
}
export type UseQuiz = (quizProps: IQuizProps) => UseQuizReturn;
